@@ -1214,6 +1214,32 @@ class Idol(Base):
         self._player = Player.load_one(self.player_id)
         return self._player
 
+    @player.setter
+    def player(self, value):
+        self._player = value
+
+
+class Tribute(Base):
+
+    @classmethod
+    def load(cls):
+        tributes = database.get_tributes()
+        tributes_dict = OrderedDict()
+        for tribute in tributes:
+            tributes_dict[tribute['playerId']] = cls(tribute)
+        return tributes_dict
+
+    @property
+    def player(self):
+        if getattr(self, '_player', None):
+            return self._player
+        self._player = Player.load_one(self.player_id)
+        return self._player
+
+    @player.setter
+    def player(self, value):
+        self._player = value
+
 
 class PlayerStatsheet(Base):
 
